from sports.nba.nba_team import NBA_Team


class ChicagoBulls(NBA_Team):
    """
    NBA Atlanta Hawks Static Information

    """
    full_name = "Chicago Bulls"
    name = "Bulls"
    team_id = 1610612741

    def __init__(self):
        """
        """
        super().__init__()
